==> collective.js.angular-1.2.16.1.tar.gz: collective.js.angular-1.2.16.1/src/collective/js/angular/resources/docs/js/versions-data.js <==
// Meta data used by the AngularJS docs app
angular.module('versionsData', [])
  .value('NG_VERSION', {
  "raw": "v1.2.16",
  "major": 1,
  "minor": 2,
  "patch": 16,
  "prerelease": [],
  "build": [],
  "version": "1.2.16",
  "codeName": "badger-enumeration",
  "full": "1.2.16"
})
  .value('NG_VERSIONS', [
  {
    "raw": "v1.2.16",
    "major": 1,
    "minor": 2,
    "patch": 16,
    "prerelease": [],
    "build": [],
    "version": "1.2.16",
    "codeName": "badger-enumeration",
    "full": "1.2.16"
  },
  {
    "raw": "v1.3.0-beta.5",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      5
    ],
    "build": [],
    "version": "1.3.0-beta.5",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.5/docs"
  },
  {
    "raw": "v1.3.0-beta.4",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      4
    ],
    "build": [],
    "version": "1.3.0-beta.4",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.4/docs"
  },
  {
    "raw": "v1.3.0-beta.3",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      3
    ],
    "build": [],
    "version": "1.3.0-beta.3",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.3/docs"
  },
  {
    "raw": "v1.3.0-beta.2",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      2
    ],
    "build": [],
    "version": "1.3.0-beta.2",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.2/docs"
  },
  {
    "raw": "v1.3.0-beta.1",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      1
    ],
    "build": [],
    "version": "1.3.0-beta.1",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.1/docs"
  },
  {
    "raw": "v1.2.15",
    "major": 1,
    "minor": 2,
    "patch": 15,
    "prerelease": [],
    "build": [],
    "version": "1.2.15",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.15/docs"
  },
  {
    "raw": "v1.2.14",
    "major": 1,
    "minor": 2,
    "patch": 14,
    "prerelease": [],
    "build": [],
    "version": "1.2.14",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.14/docs"
  },
  {
    "raw": "v1.2.13",
    "major": 1,
    "minor": 2,
    "patch": 13,
    "prerelease": [],
    "build": [],
    "version": "1.2.13",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.13/docs"
  },
  {
    "raw": "v1.2.12",
    "major": 1,
    "minor": 2,
    "patch": 12,
    "prerelease": [],
    "build": [],
    "version": "1.2.12",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.12/docs"
  },
  {
    "raw": "v1.2.11",
    "major": 1,
    "minor": 2,
    "patch": 11,
    "prerelease": [],
    "build": [],
    "version": "1.2.11",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.11/docs"
  },
  {
    "raw": "v1.2.10",
    "major": 1,
    "minor": 2,
    "patch": 10,
    "prerelease": [],
    "build": [],
    "version": "1.2.10",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.10/docs"
  },
  {
    "raw": "v1.2.9",
    "major": 1,
    "minor": 2,
    "patch": 9,
    "prerelease": [],
    "build": [],
    "version": "1.2.9",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.9/docs"
  },
  {
    "raw": "v1.2.8",
    "major": 1,
    "minor": 2,
    "patch": 8,
    "prerelease": [],
    "build": [],
    "version": "1.2.8",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.8/docs"
  },
  {
    "raw": "v1.2.7",
    "major": 1,
    "minor": 2,
    "patch": 7,
    "prerelease": [],
    "build": [],
    "version": "1.2.7",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.7/docs"
  },
  {
    "raw": "v1.2.6",
    "major": 1,
    "minor": 2,
    "patch": 6,
    "prerelease": [],
    "build": [],
    "version": "1.2.6",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.6/docs"
  },
  {
    "raw": "v1.2.5",
    "major": 1,
    "minor": 2,
    "patch": 5,
    "prerelease": [],
    "build": [],
    "version": "1.2.5",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.5/docs"
  },
  {
    "raw": "v1.2.4",
    "major": 1,
    "minor": 2,
    "patch": 4,
    "prerelease": [],
    "build": [],
    "version": "1.2.4",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.4/docs"
  },
  {
    "raw": "v1.2.3",
    "major": 1,
    "minor": 2,
    "patch": 3,
    "prerelease": [],
    "build": [],
    "version": "1.2.3",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.3/docs"
  },
  {
    "raw": "v1.2.2",
    "major": 1,
    "minor": 2,
    "patch": 2,
    "prerelease": [],
    "build": [],
    "version": "1.2.2",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.2/docs"
  },
  {
    "raw": "v1.2.1",
    "major": 1,
    "minor": 2,
    "patch": 1,
    "prerelease": [],
    "build": [],
    "version": "1.2.1",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.1/docs"
  },
  {
    "raw": "v1.2.0",
    "major": 1,
    "minor": 2,
    "patch": 0,
    "prerelease": [],
    "build": [],
    "version": "1.2.0",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.0/docs"
  },
  {
    "raw": "v1.2.0-rc.3",
    "major": 1,
    "minor": 2,
    "patch": 0,
    "prerelease": [
      "rc",
      3
    ],
    "build": [],
    "version": "1.2.0-rc.3",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.2.0-rc.3/docs"
  },
  {
    "raw": "v1.2.0-rc.2",
    "major": 1,
    "minor": 2,
    "patch": 0,
    "prerelease": [
      "rc",
      2
    ],
    "build": [],
    "version": "1.2.0-rc.2",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.2.0-rc.2/docs"
  },
  {
    "raw": "v1.1.5",
    "major": 1,
    "minor": 1,
    "patch": 5,
    "prerelease": [],
    "build": [],
    "version": "1.1.5",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.1.5/docs"
  },
  {
    "raw": "v1.1.4",
    "major": 1,
    "minor": 1,
    "patch": 4,
    "prerelease": [],
    "build": [],
    "version": "1.1.4",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.1.4/docs"
  },
  {
    "raw": "v1.1.3",
    "major": 1,
    "minor": 1,
    "patch": 3,
    "prerelease": [],
    "build": [],
    "version": "1.1.3",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.1.3/docs"
  },
  {
    "raw": "v1.1.2",
    "major": 1,
    "minor": 1,
    "patch": 2,
    "prerelease": [],
    "build": [],
    "version": "1.1.2",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.1.2/docs"
  },
  {
    "raw": "v1.1.1",
    "major": 1,
    "minor": 1,
    "patch": 1,
    "prerelease": [],
    "build": [],
    "version": "1.1.1",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.1.1/docs"
  },
  {
    "raw": "v1.1.0",
    "major": 1,
    "minor": 1,
    "patch": 0,
    "prerelease": [],
    "build": [],
    "version": "1.1.0",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.1.0/docs"
  },
  {
    "raw": "v1.0.8",
    "major": 1,
    "minor": 0,
    "patch": 8,
    "prerelease": [],
    "build": [],
    "version": "1.0.8",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.8/docs"
  },
  {
    "raw": "v1.0.7",
    "major": 1,
    "minor": 0,
    "patch": 7,
    "prerelease": [],
    "build": [],
    "version": "1.0.7",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.7/docs"
  },
  {
    "raw": "v1.0.6",
    "major": 1,
    "minor": 0,
    "patch": 6,
    "prerelease": [],
    "build": [],
    "version": "1.0.6",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.6/docs"
  },
  {
    "raw": "v1.0.5",
    "major": 1,
    "minor": 0,
    "patch": 5,
    "prerelease": [],
    "build": [],
    "version": "1.0.5",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.5/docs"
  },
  {
    "raw": "v1.0.4",
    "major": 1,
    "minor": 0,
    "patch": 4,
    "prerelease": [],
    "build": [],
    "version": "1.0.4",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.4/docs"
  },
  {
    "raw": "v1.0.3",
    "major": 1,
    "minor": 0,
    "patch": 3,
    "prerelease": [],
    "build": [],
    "version": "1.0.3",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.3/docs"
  },
  {
    "raw": "v1.0.2",
    "major": 1,
    "minor": 0,
    "patch": 2,
    "prerelease": [],
    "build": [],
    "version": "1.0.2",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.2/docs"
  },
  {
    "raw": "v1.0.1",
    "major": 1,
    "minor": 0,
    "patch": 1,
    "prerelease": [],
    "build": [],
    "version": "1.0.1",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.1/docs"
  },
  {
    "raw": "v1.0.0",
    "major": 1,
    "minor": 0,
    "patch": 0,
    "prerelease": [],
    "build": [],
    "version": "1.0.0",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.0/docs"
  },
  {
    "raw": "v1.0.0-rc2",
    "major": 1,
    "minor": 0,
    "patch": 0,
    "prerelease": [
      "rc2"
    ],
    "build": [],
    "version": "1.0.0-rc2",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.0.0-rc2/docs"
  }
]);

==> collective.js.angular-1.2.19.1.tar.gz: collective.js.angular-1.2.19.1/src/collective/js/angular/resources/docs/js/versions-data.js <==
// Meta data used by the AngularJS docs app
angular.module('versionsData', [])
  .value('NG_VERSION', {
  "raw": "v1.2.19",
  "major": 1,
  "minor": 2,
  "patch": 19,
  "prerelease": [],
  "build": [],
  "version": "1.2.19",
  "codeName": "precognitive-flashbacks",
  "full": "1.2.19"
})
  .value('NG_VERSIONS', [
  {
    "raw": "v1.2.19",
    "major": 1,
    "minor": 2,
    "patch": 19,
    "prerelease": [],
    "build": [],
    "version": "1.2.19",
    "codeName": "precognitive-flashbacks",
    "full": "1.2.19"
  },
  {
    "raw": "v1.3.0-beta.14",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      14
    ],
    "build": [],
    "version": "1.3.0-beta.14",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.14/docs"
  },
  {
    "raw": "v1.3.0-beta.13",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      13
    ],
    "build": [],
    "version": "1.3.0-beta.13",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.13/docs"
  },
  {
    "raw": "v1.3.0-beta.12",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      12
    ],
    "build": [],
    "version": "1.3.0-beta.12",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.12/docs"
  },
  {
    "raw": "v1.3.0-beta.11",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      11
    ],
    "build": [],
    "version": "1.3.0-beta.11",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.11/docs"
  },
  {
    "raw": "v1.3.0-beta.10",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      10
    ],
    "build": [],
    "version": "1.3.0-beta.10",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.10/docs"
  },
  {
    "raw": "v1.3.0-beta.9",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      9
    ],
    "build": [],
    "version": "1.3.0-beta.9",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.9/docs"
  },
  {
    "raw": "v1.3.0-beta.8",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      8
    ],
    "build": [],
    "version": "1.3.0-beta.8",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.8/docs"
  },
  {
    "raw": "v1.3.0-beta.7",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      7
    ],
    "build": [],
    "version": "1.3.0-beta.7",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.7/docs"
  },
  {
    "raw": "v1.3.0-beta.6",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      6
    ],
    "build": [],
    "version": "1.3.0-beta.6",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.6/docs"
  },
  {
    "raw": "v1.3.0-beta.5",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      5
    ],
    "build": [],
    "version": "1.3.0-beta.5",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.5/docs"
  },
  {
    "raw": "v1.3.0-beta.4",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      4
    ],
    "build": [],
    "version": "1.3.0-beta.4",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.4/docs"
  },
  {
    "raw": "v1.3.0-beta.3",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      3
    ],
    "build": [],
    "version": "1.3.0-beta.3",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.3/docs"
  },
  {
    "raw": "v1.3.0-beta.2",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      2
    ],
    "build": [],
    "version": "1.3.0-beta.2",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.2/docs"
  },
  {
    "raw": "v1.3.0-beta.1",
    "major": 1,
    "minor": 3,
    "patch": 0,
    "prerelease": [
      "beta",
      1
    ],
    "build": [],
    "version": "1.3.0-beta.1",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.3.0-beta.1/docs"
  },
  {
    "raw": "v1.2.18",
    "major": 1,
    "minor": 2,
    "patch": 18,
    "prerelease": [],
    "build": [],
    "version": "1.2.18",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.18/docs"
  },
  {
    "raw": "v1.2.17",
    "major": 1,
    "minor": 2,
    "patch": 17,
    "prerelease": [],
    "build": [],
    "version": "1.2.17",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.17/docs"
  },
  {
    "raw": "v1.2.16",
    "major": 1,
    "minor": 2,
    "patch": 16,
    "prerelease": [],
    "build": [],
    "version": "1.2.16",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.16/docs"
  },
  {
    "raw": "v1.2.15",
    "major": 1,
    "minor": 2,
    "patch": 15,
    "prerelease": [],
    "build": [],
    "version": "1.2.15",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.15/docs"
  },
  {
    "raw": "v1.2.14",
    "major": 1,
    "minor": 2,
    "patch": 14,
    "prerelease": [],
    "build": [],
    "version": "1.2.14",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.14/docs"
  },
  {
    "raw": "v1.2.13",
    "major": 1,
    "minor": 2,
    "patch": 13,
    "prerelease": [],
    "build": [],
    "version": "1.2.13",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.13/docs"
  },
  {
    "raw": "v1.2.12",
    "major": 1,
    "minor": 2,
    "patch": 12,
    "prerelease": [],
    "build": [],
    "version": "1.2.12",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.12/docs"
  },
  {
    "raw": "v1.2.11",
    "major": 1,
    "minor": 2,
    "patch": 11,
    "prerelease": [],
    "build": [],
    "version": "1.2.11",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.11/docs"
  },
  {
    "raw": "v1.2.10",
    "major": 1,
    "minor": 2,
    "patch": 10,
    "prerelease": [],
    "build": [],
    "version": "1.2.10",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.10/docs"
  },
  {
    "raw": "v1.2.9",
    "major": 1,
    "minor": 2,
    "patch": 9,
    "prerelease": [],
    "build": [],
    "version": "1.2.9",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.9/docs"
  },
  {
    "raw": "v1.2.8",
    "major": 1,
    "minor": 2,
    "patch": 8,
    "prerelease": [],
    "build": [],
    "version": "1.2.8",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.8/docs"
  },
  {
    "raw": "v1.2.7",
    "major": 1,
    "minor": 2,
    "patch": 7,
    "prerelease": [],
    "build": [],
    "version": "1.2.7",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.7/docs"
  },
  {
    "raw": "v1.2.6",
    "major": 1,
    "minor": 2,
    "patch": 6,
    "prerelease": [],
    "build": [],
    "version": "1.2.6",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.6/docs"
  },
  {
    "raw": "v1.2.5",
    "major": 1,
    "minor": 2,
    "patch": 5,
    "prerelease": [],
    "build": [],
    "version": "1.2.5",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.5/docs"
  },
  {
    "raw": "v1.2.4",
    "major": 1,
    "minor": 2,
    "patch": 4,
    "prerelease": [],
    "build": [],
    "version": "1.2.4",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.4/docs"
  },
  {
    "raw": "v1.2.3",
    "major": 1,
    "minor": 2,
    "patch": 3,
    "prerelease": [],
    "build": [],
    "version": "1.2.3",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.3/docs"
  },
  {
    "raw": "v1.2.2",
    "major": 1,
    "minor": 2,
    "patch": 2,
    "prerelease": [],
    "build": [],
    "version": "1.2.2",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.2/docs"
  },
  {
    "raw": "v1.2.1",
    "major": 1,
    "minor": 2,
    "patch": 1,
    "prerelease": [],
    "build": [],
    "version": "1.2.1",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.1/docs"
  },
  {
    "raw": "v1.2.0",
    "major": 1,
    "minor": 2,
    "patch": 0,
    "prerelease": [],
    "build": [],
    "version": "1.2.0",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.2.0/docs"
  },
  {
    "raw": "v1.2.0-rc.3",
    "major": 1,
    "minor": 2,
    "patch": 0,
    "prerelease": [
      "rc",
      3
    ],
    "build": [],
    "version": "1.2.0-rc.3",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.2.0-rc.3/docs"
  },
  {
    "raw": "v1.2.0-rc.2",
    "major": 1,
    "minor": 2,
    "patch": 0,
    "prerelease": [
      "rc",
      2
    ],
    "build": [],
    "version": "1.2.0-rc.2",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.2.0-rc.2/docs"
  },
  {
    "raw": "v1.1.5",
    "major": 1,
    "minor": 1,
    "patch": 5,
    "prerelease": [],
    "build": [],
    "version": "1.1.5",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.1.5/docs"
  },
  {
    "raw": "v1.1.4",
    "major": 1,
    "minor": 1,
    "patch": 4,
    "prerelease": [],
    "build": [],
    "version": "1.1.4",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.1.4/docs"
  },
  {
    "raw": "v1.1.3",
    "major": 1,
    "minor": 1,
    "patch": 3,
    "prerelease": [],
    "build": [],
    "version": "1.1.3",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.1.3/docs"
  },
  {
    "raw": "v1.1.2",
    "major": 1,
    "minor": 1,
    "patch": 2,
    "prerelease": [],
    "build": [],
    "version": "1.1.2",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.1.2/docs"
  },
  {
    "raw": "v1.1.1",
    "major": 1,
    "minor": 1,
    "patch": 1,
    "prerelease": [],
    "build": [],
    "version": "1.1.1",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.1.1/docs"
  },
  {
    "raw": "v1.1.0",
    "major": 1,
    "minor": 1,
    "patch": 0,
    "prerelease": [],
    "build": [],
    "version": "1.1.0",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.1.0/docs"
  },
  {
    "raw": "v1.0.8",
    "major": 1,
    "minor": 0,
    "patch": 8,
    "prerelease": [],
    "build": [],
    "version": "1.0.8",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.8/docs"
  },
  {
    "raw": "v1.0.7",
    "major": 1,
    "minor": 0,
    "patch": 7,
    "prerelease": [],
    "build": [],
    "version": "1.0.7",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.7/docs"
  },
  {
    "raw": "v1.0.6",
    "major": 1,
    "minor": 0,
    "patch": 6,
    "prerelease": [],
    "build": [],
    "version": "1.0.6",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.6/docs"
  },
  {
    "raw": "v1.0.5",
    "major": 1,
    "minor": 0,
    "patch": 5,
    "prerelease": [],
    "build": [],
    "version": "1.0.5",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.5/docs"
  },
  {
    "raw": "v1.0.4",
    "major": 1,
    "minor": 0,
    "patch": 4,
    "prerelease": [],
    "build": [],
    "version": "1.0.4",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.4/docs"
  },
  {
    "raw": "v1.0.3",
    "major": 1,
    "minor": 0,
    "patch": 3,
    "prerelease": [],
    "build": [],
    "version": "1.0.3",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.3/docs"
  },
  {
    "raw": "v1.0.2",
    "major": 1,
    "minor": 0,
    "patch": 2,
    "prerelease": [],
    "build": [],
    "version": "1.0.2",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.2/docs"
  },
  {
    "raw": "v1.0.1",
    "major": 1,
    "minor": 0,
    "patch": 1,
    "prerelease": [],
    "build": [],
    "version": "1.0.1",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.1/docs"
  },
  {
    "raw": "v1.0.0",
    "major": 1,
    "minor": 0,
    "patch": 0,
    "prerelease": [],
    "build": [],
    "version": "1.0.0",
    "isStable": true,
    "docsUrl": "http://code.angularjs.org/1.0.0/docs"
  },
  {
    "raw": "v1.0.0-rc2",
    "major": 1,
    "minor": 0,
    "patch": 0,
    "prerelease": [
      "rc2"
    ],
    "build": [],
    "version": "1.0.0-rc2",
    "isStable": false,
    "docsUrl": "http://code.angularjs.org/1.0.0-rc2/docs"
  }
]);
